/*
 * ============================================================================
 * Licensed Materials - Property of IBM
 * Project  Zero
 *
 * (C) Copyright IBM Corp. 2007  All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ============================================================================
 */


import zero.json.Json
import zero.ide.services.ModuleGroupUtils

import zero.appbuilder.resources.MessageHandler

/**
 *
 * @success 200 A map of name-value pairs representing user-specific settings.
 * @format application/json
 *
 */
def onList()
{
    request.view = 'JSON'
    request.json.output = getSettings()
    render()
}

/**
 *
 * @success 200 The value for the given setting.
 * @error 404 If the setting does not exist.
 * @format application/json
 *
 */
def onRetrieve()
{
    def settings = getSettings()
    def settingsId = request.params.settingsId[]
    def value = settings[settingsId]
    
    if (!value)
    {
        request.status = 404
        return
    }
    
    request.view = 'JSON'
    request.json.output = value
    render()
}


/**
 *
 * @success 204 Updates the setting value for {settingsId} 
 * @format application/json
 *
 */
def onUpdate()
{
	def settingsId = request.params.settingsId[]
	def readOnlySettings = ['fileSeparator',
	                        'cliModuleGroup',
	                        'defaultEditor',
	                        'filehandlers']
	
	if (readOnlySettings.contains(settingsId)) {
		request.status = 405
		return
	}
	
    zpost('/storage#lock', '/settings')

    if (!zcontains('/storage/settings')) {
        storage.settings = [:]
    }

    storage.settings[settingsId] = Json.decode(request.input[])

    zpost('/storage#unlock', '/settings')

    request.status = 204
}

 
def getSettings()
{
	def settings = zget('/storage/settings', [:])
     
	if (!settings.containsKey('defaultPath'))
	{
		def userHome = System.getProperty('user.home')
		settings.put('defaultPath', userHome)
	}
     
	settings.put('fileSeparator', File.separator)
	
	String cliModuleGroup=ModuleGroupUtils.getCurrentModuleGroup();
	settings.put('cliModuleGroup', cliModuleGroup)
	     
	if (!settings.containsKey('lastModuleGroup'))
	{      
		settings.put('lastModuleGroup', cliModuleGroup)
	}
	
	settings.put('defaultEditor', config.appbuilder.defaultEditor[])
	settings.put('filehandlers', config.appbuilder.filehandlers[])
	
	return settings
}
